#!/bin/bash
#
# source: http://downloads.sourceforge.net/project/lcms/lcms/2.3/lcms2-2.3.tar.gz
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft="lcms2"
softversion="2.3"
arch="i486"
cpu="i686"
packageversion="72.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest

#------------------Set correct permissions

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --mandir=/usr/man \
  --disable-static

make -j6
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

gzip -9 $dest/usr/man/*/*.?

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING INSTALL README* $dest/usr/doc/$soft-$softversion

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler---------------------------------------------------|
lcms2: lcms2 - Little CMS Engine API
lcms2:
lcms2: Little CMS 2 color management library development headers
lcms2: 
lcms2:
lcms2: 
lcms2: 
lcms2:
lcms2:
lcms2:
lcms2:
EODESC


mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5